#!/usr/bin/perl
package main;

&do_require_package("report");
&do_require_package("makeidx");
&do_require_package("alltt");
&do_require_package("amsmath");
&do_require_package("color");
&do_require_package("html");

&do_require_package('inputenc');
&do_inputenc_utf8;

$STYLESHEET = '';
$STYLESHEET_CASCADE = '<!--#include virtual="/navigation/styles.html" -->';

$nodename='';

sub custom_title_hook{
   local($title) = @_;

   local($name) = $nodename;

   unless ($name)
   {
      $name = lc($title);
      $name=~s/[^\w]//g;

      $name=~s/^\d+//;
   }

   $nodename = '';

   $name
}

sub make_name {
    local($sec_name, $packed_curr_sec_id) = @_;
    local($title,$making_name,$saved) = ('',1,'');
    if ($LONG_TITLES) {
        $saved = $_;
        &set_sectioning_title($_) if /^$sections_rx/; # modified
        $title = &make_long_title($TITLE)
            unless ((! $TITLE) || ($TITLE eq $default_title));
        $_ = $saved;
    } elsif ($CUSTOM_TITLES) {
        $saved = $_;
        &set_sectioning_title($_) if /^$sections_rx/; # modified
        $title = &custom_title_hook($TITLE)
            unless ((! $TITLE) || ($TITLE eq $default_title));
        $_ = $saved;
    }
    if ($title) {
        #ensure no more than 32 characters, including .html extension
        $title =~ s/^(.{1,27}).*$/$1/;
        ++$OUT_NODE;
        join("", ${PREFIX}, $title, $EXTN);
    } else {
    # Remove 0's from the end of $packed_curr_sec_id
        $packed_curr_sec_id =~ s/(_0)*$//;
        $packed_curr_sec_id =~ s/^\d+$//o; # Top level file
        join("",($packed_curr_sec_id ?
            "${PREFIX}$NODE_NAME". ++$OUT_NODE : $sec_name), $EXTN);
    }
}

sub set_sectioning_title{
  local($_) = @_;

  if (/$section_rx/)
  {
    ($before, $cmd, $after) = ($`, $1.$2, $4.$');

    if (defined($unnumbered_section_commands{$cmd}))
    {
       &process_command($section_rx, $_[0]);
    }
    elsif ($cmd eq 'printkeywords')
    {
       $TITLE = "Some Definitions";
    }
    elsif ($cmd eq 'listofexercises')
    {
       $TITLE = "List of Exercises";
    }
    else
    {
       local($align, $dummy) = &get_next_optional_argument;

       $TITLE = &missing_braces
           unless $after=~s/$next_pair_rx/$TITLE=$2;''/eo;
    }

    $br_id = ++$global{'max_id'};
    $TITLE = &translate_environments("$O$br_id$C$TITLE$O$br_id$C");
    $TITLE = &simplify($TITLE);
  }
}


%sectiontitles = ();

sub do_cmd_sectionlabel{
    local($_) = @_;
    local($label, $title);

    $label = &missing_braces unless (
        (s/$next_pair_pr_rx/$label = $2;''/eo)
        ||(s/$next_pair_rx/$label = $2;''/eo));

    $title = &missing_braces unless (
        (s/$next_pair_pr_rx/$title = $2;''/eo)
        ||(s/$next_pair_rx/$title = $2;''/eo));

    $sectiontitles{$label}=$title;

    &anchor_label($label,$CURRENT_FILE,$_);
}

sub do_cmd_sectionref{
   local($_) = @_;

   local($text,$pat) = &get_next_optional_argument;

   local($label, $id);

   $label = &missing_braces unless
       s/$next_pair_pr_rx/$id=$1;$label = $2;''/eo;

   local($id2) = ++$global{'max_id'};

   unless ($text)
   {
      local ($num) = $symbolic_labels{$label};

      $text = $sectiontitles{$label} ?
              $sectiontitles{$label} :
              $label;

      $text=~s/<tex2html_([a-zA-Z]+)_deferred>/\\deferred$1 /g;

      if ($num)
      {
         $text = "\\S " . $num. ". " . $text;
      }
   }

   "\\htmlref$OP$id$CP$text$OP$id$CP$OP$id2$CP$label$OP$id2$CP".$_;
}

sub do_cmd_setnode{
  local($_) = @_;

  local($id);

  $nodename = &missing_braces unless
    s/$next_pair_pr_rx/$id=$1,$nodename=$2;''/eo;

  $_;
}

sub do_cmd_qt{
  local($_) = @_;
  local($text);

  $text = &missing_braces unless s/$next_pair_pr_rx/$text=$2;''/eo;

  "“$text”$_";
}

sub do_cmd_keywordfmt{
   local($_) = @_;

   local($text);

   $text = &missing_braces unless
     s/$next_pair_pr_rx/$text=$2;''/eo;

   "<EM>$text</EM>".$_;
}



$ADDRESS = '';

$MAX_LINK_DEPTH=1;
$child_name='';
$NUMBERED_FOOTNOTES=1;
$TOP_NAVIGATION=1;
$BOTTOM_NAVIGATION=1;

$CHILDLINE = "<BR>";
sub upper_child_line{ '<BR>'; };

$UPCHAR = '<font style="font-size: xx-large; font-weight: bold;">&#x21E7;</font>';
$PREVCHAR = '<font style="font-size: xx-large; font-weight: bold;">&#x21E6;</font>';
$NEXTCHAR = '<font style="font-size: xx-large; font-weight: bold;">&#x21E8;</font>';

$mainnav = '';

sub top_navigation_panel{
  local($gonext) = $NEXT;
  local($goprev) = $PREVIOUS;
  local($goup) = $UP;

  $USING_STYLES=0;

  if ($gonext=~s/<tex2html_next_page_visible_mark>/$NEXTCHAR<BR>Next/)
  {
     $gonext = "<div class=\"navigatenext\">$gonext</div>";
  }
  else
  {
    $gonext=~s/<tex2html_next_page_inactive_visible_mark>/<div class="disnavigatenext">$NEXTCHAR<BR>Next<\/div>/;
  }

  if ($goprev=~s/<tex2html_previous_page_visible_mark>/$PREVCHAR<BR>Prev/)
  {
     $goprev = "<div class=\"navigateprev\">$goprev</div>";
  }
  else
  {
    $goprev=~s/<tex2html_previous_page_inactive_visible_mark>/<div class="disnavigateprev">$PREVCHAR<BR>Prev<\/div>/;
  }

  if ($goup=~s/<tex2html_up_visible_mark>/$UPCHAR<BR>Up/)
  {
     $goup = "<div class=\"navigateup\">$goup</div>";
  }
  else
  {
    $goup=~s/<tex2html_up_inactive_visible_mark>/<div class="disnavigateup">$UPCHAR<BR>Up<\/div>/;
  }

  unless ($mainnav)
  {
     $mainnav = &add_child_links('', $file, $depth, $child_star, $key, @keys);
  }

  local($nav) = $mainnav;

<<_END_HEADER_TEXT;
 <!--#include virtual="/navigation/header.html" -->
    <div id="sidebar">
     <div style="text-align: center;">
     <A HREF="http://www.dickimaw-books.com/latex/minexample/index.html">Document Home Page</A><P>
     </div>
    <p>
    <div class="navigate">
    $goprev $goup $gonext
    <br>
    </div>
    $nav
    <div class="idxnav"></div>
    </div>
    <div id="main">
_END_HEADER_TEXT
}

sub bot_navigation_panel{
  local($gonext) = $NEXT;
  local($goprev) = $PREVIOUS;
  local($goup) = $UP;

  if ($gonext=~s/<tex2html_next_page_visible_mark>/$NEXTCHAR/)
  {
     $gonext = "<div class=\"bottomnavigatenext\">$gonext</div>";
  }
  else
  {
    $gonext=~s/<tex2html_next_page_inactive_visible_mark>/<div
class="bottomdisnavigatenext">$NEXTCHAR<\/div>/;
  }

  if ($goprev=~s/<tex2html_previous_page_visible_mark>/$PREVCHAR/)
  {
     $goprev = "<div class=\"bottomnavigateprev\">$goprev</div>";
  }
  else
  {
    $goprev=~s/<tex2html_previous_page_inactive_visible_mark>/<div
class="bottomdisnavigateprev">$PREVCHAR<\/div>/;
  }

  if ($goup=~s/<tex2html_up_visible_mark>/$UPCHAR/)
  {
     $goup = "<div class=\"bottomnavigateup\">$goup</div>";
  }
  else
  {
    $goup=~s/<tex2html_up_inactive_visible_mark>/<div class="bottomdisnavigateup">$UPCHAR<\/div>/;
  }


<<"_END_TEXT";
      $goprev
      $goup
      $gonext
     <!--#set var="CopyYear" value="2012" -->
     <!--#include virtual="/navigation/footer.shtml" -->
    </div>
_END_TEXT
}

eval(<<'_END_EVAL');
sub replace_markers {
    &find_quote_ligatures;
    &replace_general_markers;
    &replace_extra_markers;
    &text_cleanup;
    &replace_sensitive_markers;
    &replace_init_file_mark if (/$init_file_mark/);
    &replace_file_marks;
    &post_replace_markers;
}

sub do_env_alltt {
    local ($_) = @_;
    local($closures,$reopens,$alltt_start,$alltt_end,@open_block_tags);

    $alltt_start = "\n<DIV CLASS=\"alltt\" ALIGN=\"LEFT\">\n";
    $alltt_end = "\n</DIV>\n";

    # get the tag-strings for all open tags
    local(@keep_open_tags) = @$open_tags_R;
    ($closures,$reopens) = &preserve_open_tags() if (@$open_tags_R);

    # get the tags for text-level tags only
    $open_tags_R = [ @keep_open_tags ];
    local($local_closures, $local_reopens);
    ($local_closures, $local_reopens,@open_block_tags) = &preserve_open_block_tags
	if (@$open_tags_R);

    $open_tags_R = [ @open_block_tags ];

    do {
	local($open_tags_R) = [ @open_block_tags ];
	local(@save_open_tags) = ();

	local($cnt) = ++$global{'max_id'};
	$_ = join('',"$O$cnt$C\\tt$O", ++$global{'max_id'}, $C
		, $_ , $O, $global{'max_id'}, "$C$O$cnt$C");

	$_ = &translate_environments($_);
	$_ = &translate_commands($_) if (/\\/);

	# preserve space-runs, using &nbsp;
	while (s/(\S) ( +)/$1$2;SPMnbsp;/g){};
	s/(<BR>) /$1;SPMnbsp;/g;

	$_ = join('', $closures, $alltt_start , $local_reopens
		, $_
		, &balance_tags() #, $local_closures
		, $alltt_end, $reopens);
	undef $open_tags_R; undef @save_open_tags;
    };

    $open_tags_R = [ @keep_open_tags ];
    $_;
}
_END_EVAL

sub replace_extra_markers{
  s/<tex2html_glstoc_deferred>/\\deferredglstoc /eo;
  s/<div class="idxnav"><\/div>/$sidepanelcontents/m;
  $sidepanelcontents = '';
}


sub do_cmd_incPgfOrGraphics{
  &do_cmd_incGraphics(@_);
}

sub do_cmd_incGraphics{
   local($_) = @_;
   local($img, $alt);

   local($opt,$pat) = &get_next_optional_argument;

   if ($opt=~/\balt\s*=\s*([^,]+)/i)
   {
      $alt = "ALT=\"$1\"";
   }
   else
   {
      $alt = '';
   }

   $img = &missing_braces unless
      s/$next_pair_pr_rx/$img=$2;''/eo;

   "<IMG SRC=\"$img.png\" $alt>";
}

sub do_cmd_today{

   my ($sec,$min,$hr,$day,$mon,$year) = localtime(time);

   $year += 1900;
   $mon++;

   sprintf("%d-%.2d-%.2d", $year, $mon, $day).$_[0];
}

sub make_named_href {
    local($name, $link, $text) = @_;
    $text =~ s/<A .*><\/A>//go;
    $text = &simplify($text);
    if ($text eq $link) { $text =~ s/~/&#126;/g; }
    $link =~ s/~/&#126;/g;
    $link =~ s/\\(html)?url\s*(($O|$OP)\d+($C|$CP))([^<]*)\2/$5/;
    $link =~ s:(<TT>)?<A [^>]*>([^<]*)</A>(</TT>)?(([^<]*)|$):$2$4:;

    my $target = '';

    if ($link=~m|^https?://| and not $link=~/^$t_homepage/)
    {
       $target = 'TARGET="_blank"';
    }
    if (!($name)) {"<A $target\n HREF=\"$link\">$text</A>";}
    elsif ($text =~ /^\w/) {"<A $target NAME=\"$name\"\n HREF=\"$link\">$text</A>";}
    else {"<A $target NAME=\"$name\"\n HREF=\"$link\">$text</A>";}
}

sub make_real_href {
    local($link, $text) = @_;
    $href_name++;

    my $htarget = '';

    $text =~ s/<A .*><\/A>//go;
    if ($text eq $link) { $text =~ s/~/&#126;/g; }
    $link =~ s/~/&#126;/g;
    $link =~ s/\\(html)?url\s*(($O|$OP)\d+($C|$CP))([^<]*)\2/$5/;
    $link =~ s:(<TT>)?<A [^>]*>([^<]*)</A>(</TT>)?(([^<]*)|$):$2$4:;
    $text = &simplify($text);

    if ($target)
    {
      $htarget = ' TARGET="'.$target.'"';
    }
    else
    {
       if ($link=~m|^https?://| and not $link=~/^$t_homepage/)
       {
          $htarget = ' TARGET="_blank"';
       }
    }


    "<A NAME=\"tex2html$href_name\"$htarget\n  HREF=\"$link\">$text</A>";
}

$t_baseurl = '';
$t_homepage = '';

sub do_cmd_setbaseurl{
  local($_) = @_;

  $t_baseurl = &missing_braces unless
       s/$next_pair_pr_rx/$id=$1;$t_baseurl = $2;''/eo;

  $t_homepage = $t_baseurl;

  $t_homepage=~s|^(https?://[^/]+/).*|$1|g;

  $_;
}

sub do_cmd_baseurl{
   $t_baseurl.$_[0];
}

1;	# Must be last line
